==> estateplat-common-1.2.4-20191130.080413-197-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产登记收费项目
 *
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sfxm")
public class BdcSfxm implements Serializable {
    @Id
    //收费项目id
    public String sfxmid;
    //收费单信息id
    public String sfxxid;
    //收费项目名称
    public String sfxmmc;
    //序号
    public Integer xh;
    //序号
    public Integer sl;
    //金额
    public Double je;
    //标准
    public String bz;
    //单位
    public String dw;
    //收费项目代码
    public String sfxmdm;
    //标准金额
    public Double bzje;


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 收取比例
     */
    private Double sfbl;
    //权利人类型
    private String qlrlx;
    //付费方式
    private String fffs;
    //付费终端
    private String ffzd;
    //是否集中缴费
    private String sfjzjf;

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public Integer getSl() {
        return sl;
    }

    public void setSl(Integer sl) {
        this.sl = sl;
    }

    public Double getJe() {
        return je;
    }

    public void setJe(Double je) {
        this.je = je;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getSfxmdm() {
        return sfxmdm;
    }

    public void setSfxmdm(String sfxmdm) {
        this.sfxmdm = sfxmdm;
    }

    public Double getSfbl() {
        return sfbl;
    }

    public void setSfbl(Double sfbl) {
        this.sfbl = sfbl;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getFffs() {
        return fffs;
    }

    public void setFffs(String fffs) {
        this.fffs = fffs;
    }

    public String getFfzd() {
        return ffzd;
    }

    public void setFfzd(String ffzd) {
        this.ffzd = ffzd;
    }

    public Double getBzje() {
        return bzje;
    }

    public void setBzje(Double bzje) {
        this.bzje = bzje;
    }

    public String getSfjzjf() {
        return sfjzjf;
    }

    public void setSfjzjf(String sfjzjf) {
        this.sfjzjf = sfjzjf;
    }
}

==> estateplat-common-1.2.4-20200428.132717-331-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产登记收费项目
 *
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sfxm")
public class BdcSfxm implements Serializable {
    @Id
    //收费项目id
    public String sfxmid;
    //收费单信息id
    public String sfxxid;
    //收费项目名称
    public String sfxmmc;
    //序号
    public Integer xh;
    //序号
    public Double sl;
    //金额
    public Double je;
    //标准
    public String bz;
    //单位
    public String dw;
    //收费项目代码
    public String sfxmdm;
    //标准金额
    public Double bzje;


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 收取比例
     */
    private Double sfbl;
    //权利人类型
    private String qlrlx;
    //付费方式
    private String fffs;
    //付费终端
    private String ffzd;
    //是否集中缴费
    private String sfjzjf;
    //减免依据
    private String jmyj;

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }

    public Double getJe() {
        return je;
    }

    public void setJe(Double je) {
        this.je = je;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getSfxmdm() {
        return sfxmdm;
    }

    public void setSfxmdm(String sfxmdm) {
        this.sfxmdm = sfxmdm;
    }

    public Double getSfbl() {
        return sfbl;
    }

    public void setSfbl(Double sfbl) {
        this.sfbl = sfbl;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getFffs() {
        return fffs;
    }

    public void setFffs(String fffs) {
        this.fffs = fffs;
    }

    public String getFfzd() {
        return ffzd;
    }

    public void setFfzd(String ffzd) {
        this.ffzd = ffzd;
    }

    public Double getBzje() {
        return bzje;
    }

    public void setBzje(Double bzje) {
        this.bzje = bzje;
    }

    public String getSfjzjf() {
        return sfjzjf;
    }

    public void setSfjzjf(String sfjzjf) {
        this.sfjzjf = sfjzjf;
    }

    public String getJmyj() {
        return jmyj;
    }

    public void setJmyj(String jmyj) {
        this.jmyj = jmyj;
    }
}
